betty.test_utils.ancestry.locale - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# Source code for betty.test_utils.ancestry.locale

    """
    Test utilities for :py:mod:`betty.ancestry.locale`.
    """

    from betty.ancestry.locale import HasLocale

    class DummyHasLocale(HasLocale):
        """
        A dummy :py:class:`betty.ancestry.locale.HasLocale` implementation.
        """

        pass